Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/richdocuments.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/appconfig.php')
-rw-r--r--lib/appconfig.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/appconfig.php b/lib/appconfig.php
index 1f4463d0..a83ceae3 100644
--- a/lib/appconfig.php
+++ b/lib/appconfig.php
@@ -1,6 +1,6 @@
<?php
/**
* ownCloud - Documents App
*
* @author Victor Dubiniuk
* @copyright 2015 Victor Dubiniuk victor.dubiniuk@gmail.com
@@ -9,12 +9,12 @@
* later.
*/
-namespace OCA\Documents;
+namespace OCA\Richdocuments;
use \OCP\IConfig;
class AppConfig{
- private $appName = 'documents';
+ private $appName = 'richdocuments';
private $defaults = [
'converter' => 'off',
'converter_url' => 'http://localhost:16080',
@@ -1,6 +1,6 @@
<?php
/**
- * ownCloud - Documents App
+ * ownCloud - Richdocuments App
*
* @author Victor Dubiniuk